// 展开所有数据
export function expandAllNodes(projects) {
	let tableData = []
	projects.forEach(p => {
		if (Array.isArray(p.boxList)) {
			p.boxList.forEach(b => {
				// 继续判断有多少单机，主机、新风机、换热站、末端单机数量取最大值
				let maxCnt = _calcMaxStandaloneCnt(b)
				for (let i = 0; i < maxCnt; i++) {
					let hpStandalone = b.hostCtrl && i < b.hostCtrl.length ? b.hostCtrl[i] : {}
					let dhStandalone = b.newTrendCtrl && i < b.newTrendCtrl.length ? b.newTrendCtrl[i] : {}
					let hexStandalone = b.hex && i < b.hex.length ? b.hex[i] : {}
					let cbStandalone = b.end && i < b.end.length ? b.end[i] : {}
					tableData.push({
						projectId: p.project_auto_id,
						projectName: p.projectName,
						boxId: b.box_id,
						boxName: b.boxName,
						runStatus: b.runStatus,
						runMode: b.runMode,
						hpCnt: b.hostCtrl && b.hostCtrl.length,
						dhCnt: b.newTrendCtrl && b.newTrendCtrl.length,
						hexCnt: b.hex && b.hex.length,
						cbCnt: b.end && b.end.length,
						maxCnt,
						...hpStandalone,
						...dhStandalone,
						...hexStandalone,
						...cbStandalone
					})
				}
			})
		}
	})
	return _getEndSpanRows(tableData);
}

// 合并行数据
export function mergeTableRows(data, merge) {
	if (!merge || merge.length === 0) {
		return data
	}
	merge.forEach(m => {
		const mList = {}
		let spliceLocation = merge.indexOf(m)
		data = data.map((v, index) => {
			const rowVal = v[m]
			if (mList[rowVal] && mList[rowVal].newIndex === index) {
				let flag = false
				let mergeSolve = merge.slice(0, spliceLocation)
				// console.log(">>> mergeSolve: ", mergeSolve)
				mergeSolve.slice(0, spliceLocation).forEach(mergeItem => {
					// console.log(">>> mergeItem: ", mergeItem)
					// console.log(">>> data[index][mergeItem]: ", data[index][mergeItem])
					// console.log(">>> data[index - 1][mergeItem]: ", data[index - 1][mergeItem])
					if (data[index][mergeItem] == data[index - 1][mergeItem]) {
						flag = true
					}
				})
				if (m == merge[0]) {
					flag = true
				}
				if (flag) {
					mList[rowVal]["num"]++
					mList[rowVal]["newIndex"]++
					data[mList[rowVal]["index"]][m + "-span"].rowspan++
					v[m + "-span"] = {
						rowspan: 0,
						colspan: 0,
					}
				} else {
					mList[rowVal] = {
						num: 1,
						index: index,
						newIndex: index + 1,
					}
					v[m + "-span"] = {
						rowspan: 1,
						colspan: 1,
					}
				}
			} else {
				mList[rowVal] = {
					num: 1,
					index: index,
					newIndex: index + 1,
				}
				v[m + "-span"] = {
					rowspan: 1,
					colspan: 1,
				}
			}
			return v
		})
	})
	return data
}

// 取最大单机数(最多显示2行)
function _calcMaxStandaloneCnt(box) {
	let hpStandaloneCnt = box.hostCtrl ? box.hostCtrl.length : 0
	let dhStandaloneCnt = box.newTrendCtrl ? box.newTrendCtrl.length : 0
	let hexStandaloneCnt = box.hex ? box.hex.length : 0
	// 需求：末端最多显示一行，其他类型设备最多两行。如果其他类型设备超过一行，末端需要合并
	// 所以就无需考虑末端单机的个数
	let max = Math.max(hpStandaloneCnt, dhStandaloneCnt, hexStandaloneCnt)
	return Math.min(2, max)
}

// 计算每条记录末端所占的行数
function _getEndSpanRows(tableData) {
	tableData.map((td, index) => {
		let previous = tableData[index - 1]
		if (td.maxCnt > 1 && previous.spanRows < 2) {
			td.spanRows = td.maxCnt
		} else if (index > 0 && previous.spanRows > 1) {
			td.spanRows = 0
		} else {
			td.spanRows = 1
		}
		tableData[index] = td
		return td
	})
	return tableData
}
